@@ -2,7 +2,7 @@ package enum::prefix;
 use warnings;
 use strict;
 use 5.006;
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 my $ident = '[^\W_0-9]\w*';
 
@@ -41,7 +41,7 @@ enum::prefix
 
 =head1 SYNOPSIS
 
-	use enum::prefix BUG => qw(_STATUS CLOSE FIXED REOPEN);
+	use enum::prefix BUG_ => qw(STATUS CLOSE FIXED REOPEN);
 	# BUG_CLOSE = 0, BUG_FIXED = 1, BUG_REOPEN = 2;
 	# BUG_STATUS(1) eq 'FIXED';
 
